Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(53)

Unified Diff: build/android/pylib/instrumentation/dispatch.py

Issue 12544033: [Android] Rewrite base test result classes. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: build/android/pylib/instrumentation/dispatch.py
diff --git a/build/android/pylib/instrumentation/dispatch.py b/build/android/pylib/instrumentation/dispatch.py
index 8c7e77910133757dc19975366ae72304cebd72b1..2eedff3c09ba8b3d998f84048a09f361cdf2f5cc 100644
--- a/build/android/pylib/instrumentation/dispatch.py
+++ b/build/android/pylib/instrumentation/dispatch.py
@@ -8,8 +8,8 @@ import logging
import os
from pylib import android_commands
+from pylib.base import base_test_result
from pylib.base import shard
-from pylib.base import test_result
from pylib.uiautomator import test_package as uiautomator_package
import test_package
@@ -26,7 +26,7 @@ def Dispatch(options):
options: Command line options.
Returns:
A TestResults object holding the results of the Java tests.
Raises:
Exception: when there are no attached devices.
@@ -80,7 +80,7 @@ def Dispatch(options):
if not tests:
logging.warning('No instrumentation tests to run with current args.')
- return test_result.TestResults()
+ return base_test_result.TestRunResults()
tests *= options.number_of_runs

Powered by Google App Engine
@@ -26,7 +26,7 @@ def Dispatch(options):
options: Command line options.
Returns:
- A TestResults object holding the results of the Java tests.
+ A TestRunResults object holding the results of the Java tests.
Raises:
Exception: when there are no attached devices.
This is Rietveld 408576698